summaryrefslogtreecommitdiff
path: root/src/mongo/db/query/find.h
diff options
context:
space:
mode:
authorAndy Schwerin <schwerin@mongodb.com>2015-05-27 19:36:59 -0400
committerAndy Schwerin <schwerin@mongodb.com>2015-06-05 14:21:56 -0400
commit51c2064d518140fbeae62f9d7ba29f1d69fb530f (patch)
treeb6d97eb91b4ac76279eb983234c6ec63ac44a8c6 /src/mongo/db/query/find.h
parent1cf11a282870c26ce7d963fb3a6c3329b39d90a2 (diff)
downloadmongo-51c2064d518140fbeae62f9d7ba29f1d69fb530f.tar.gz
SERVER-18277 Stronger locking rules for CurOp and OpDebug.
Diffstat (limited to 'src/mongo/db/query/find.h')
-rw-r--r--src/mongo/db/query/find.h19
1 files changed, 8 insertions, 11 deletions
diff --git a/src/mongo/db/query/find.h b/src/mongo/db/query/find.h
index 650a6f0e4fd..81803b66364 100644
--- a/src/mongo/db/query/find.h
+++ b/src/mongo/db/query/find.h
@@ -38,7 +38,6 @@
namespace mongo {
- class CurOp;
class NamespaceString;
class OperationContext;
@@ -111,27 +110,27 @@ namespace mongo {
bool isTailable);
/**
* Fills out CurOp with information about this query.
*/
- void beginQueryOp(const NamespaceString& nss,
+ void beginQueryOp(OperationContext* txn,
+ const NamespaceString& nss,
const BSONObj& queryObj,
int ntoreturn,
- int ntoskip,
- CurOp* curop);
+ int ntoskip);
/**
* Fills out CurOp with information regarding this query's execution.
*
* Uses explain functionality to extract stats from 'exec'.
*
* The database profiling level, 'dbProfilingLevel', is used to conditionalize whether or not we
* do expensive stats gathering.
*/
- void endQueryOp(PlanExecutor* exec,
+ void endQueryOp(OperationContext* txn,
+ PlanExecutor* exec,
int dbProfilingLevel,
int numResults,
- CursorId cursorId,
- CurOp* curop);
+ CursorId cursorId);
/**
* Constructs a PlanExecutor for a query with the oplogReplay option set to true,
@@ -155,7 +154,6 @@ namespace mongo {
const char* ns,
int ntoreturn,
long long cursorid,
- CurOp& curop,
int pass,
bool& exhaust,
bool* isCursorAuthorized);
@@ -166,7 +164,6 @@ namespace mongo {
std::string runQuery(OperationContext* txn,
QueryMessage& q,
const NamespaceString& ns,
- CurOp& curop,
Message &result);
} // namespace mongo
@@ -111,27 +110,27 @@ namespace mongo {
bool isTailable);
/**
- * Fills out CurOp with information about this query.
+ * Fills out the CurOp for "txn" with information about this query.
*/
@@ -111,27 +110,27 @@ namespace mongo {
/**
- * Fills out CurOp with information regarding this query's execution.
+ * Fills out CurOp for "txn" with information regarding this query's execution.
*
* Uses explain functionality to extract stats from 'exec'.